.. _data_science:

========================
Jupyter for Data Science
========================

The purpose of this page is to highlight kernels and other projects that are
central to the usage of Jupyter in data science. This page is not meant to be
comprehensive or unbiased, but rather to provide an opinionated view of the
usage of Jupyter in data science based on our interactions with users.

The following Jupyter kernels are widely used in data science:

* python
    - IPython (`GitHub Repo <https://github.com/ipython/ipykernel>`__)
* R
    - IRkernel (`Documentation <https://irkernel.github.io/>`__, `GitHub Repo <https://github.com/IRkernel/IRkernel>`__)
    - IRdisplay (`GitHub Repo <https://github.com/IRkernel/IRdisplay>`__)
    - repr (`GitHub Repo <https://github.com/IRkernel/repr>`__)
* Julia
     - IJulia Kernel (`GitHub Repo <https://github.com/JuliaLang/IJulia.jl>`__)
     - Interactive Widgets (`GitHub Repo <https://github.com/JuliaLang/Interact.jl>`__)
* Bash (`GitHub Repo <https://github.com/takluyver/bash_kernel>`__)
